
function [VOI, STATES, ALGEBRAIC, CONSTANTS] = uv_type_bran_exported()
    % This is the "main function".  In Matlab, things work best if you rename this function to match the filename.
   [VOI, STATES, ALGEBRAIC, CONSTANTS] = solveModel();
end

function [algebraicVariableCount] = getAlgebraicVariableCount()
    % Used later when setting a global variable with the number of algebraic variables.
    % Note: This is not the "main method".
    algebraicVariableCount =97;
end
% There are a total of 25 entries in each of the rate and state variable arrays.
% There are a total of 148 entries in the constant variable array.
%

function [VOI, STATES, ALGEBRAIC, CONSTANTS] = solveModel()
    % Create ALGEBRAIC of correct size
    global algebraicVariableCount;  algebraicVariableCount = getAlgebraicVariableCount();
    % Initialise constants and state variables
    [INIT_STATES, CONSTANTS] = initConsts;

    % Set timespan to solve over
    tspan = [0, 80];

    % Set numerical accuracy options for ODE solver
    options = odeset('RelTol', 1e-06, 'AbsTol', 1e-06, 'MaxStep', 0.01);

    % Solve model with ODE solver
    [VOI, STATES] = ode15s(@(VOI, STATES)computeRates(VOI, STATES, CONSTANTS), tspan, INIT_STATES, options);

    % Compute algebraic variables
    [RATES, ALGEBRAIC] = computeRates(VOI, STATES, CONSTANTS);
    ALGEBRAIC = computeAlgebraic(ALGEBRAIC, CONSTANTS, STATES, VOI);

    % Plot state variables against variable of integration
%     [LEGEND_STATES, LEGEND_ALGEBRAIC, LEGEND_VOI, LEGEND_CONSTANTS] = createLegends();
    figure();
    plot(VOI, STATES);
%     xlabel(LEGEND_VOI);
%     l = legend(LEGEND_STATES);
%     set(l,'Interpreter','none');
end

% function [LEGEND_STATES, LEGEND_ALGEBRAIC, LEGEND_VOI, LEGEND_CONSTANTS] = createLegends()
%     LEGEND_STATES = ''; LEGEND_ALGEBRAIC = ''; LEGEND_VOI = ''; LEGEND_CONSTANTS = '';
%     LEGEND_VOI = strpad('time in component environment (second)');
%     LEGEND_CONSTANTS(:,1) = strpad('kappa in component main (pascal)');
%     LEGEND_CONSTANTS(:,143) = strpad('f_a_r1 in component main (pascal)');
%     LEGEND_STATES(:,1) = strpad('r1 in component airway (meter)');
%     LEGEND_STATES(:,2) = strpad('r1 in component airway1 (meter)');
%     LEGEND_STATES(:,3) = strpad('r1 in component airway2 (meter)');
%     LEGEND_STATES(:,4) = strpad('r1 in component airway21 (meter)');
%     LEGEND_STATES(:,5) = strpad('v_d in component airway (m3_per_s)');
%     LEGEND_STATES(:,6) = strpad('v_d in component airway1 (m3_per_s)');
%     LEGEND_STATES(:,7) = strpad('v_d in component airway2 (m3_per_s)');
%     LEGEND_STATES(:,8) = strpad('v_d in component airway21 (m3_per_s)');
%     LEGEND_ALGEBRAIC(:,38) = strpad('Ptm_r1 in component airway (pascal)');
%     LEGEND_ALGEBRAIC(:,56) = strpad('Ptm_r1 in component airway1 (pascal)');
%     LEGEND_ALGEBRAIC(:,76) = strpad('Ptm_r1 in component airway2 (pascal)');
%     LEGEND_ALGEBRAIC(:,93) = strpad('Ptm_r1 in component airway21 (pascal)');
%     LEGEND_ALGEBRAIC(:,25) = strpad('u_out in component airway (J_per_m3)');
%     LEGEND_ALGEBRAIC(:,40) = strpad('u_out in component airway1 (J_per_m3)');
%     LEGEND_ALGEBRAIC(:,59) = strpad('u_out in component airway2 (J_per_m3)');
%     LEGEND_ALGEBRAIC(:,84) = strpad('u_out in component airway21 (J_per_m3)');
%     LEGEND_ALGEBRAIC(:,36) = strpad('tau_r1 in component airway (pascal)');
%     LEGEND_ALGEBRAIC(:,53) = strpad('tau_r1 in component airway1 (pascal)');
%     LEGEND_ALGEBRAIC(:,74) = strpad('tau_r1 in component airway2 (pascal)');
%     LEGEND_ALGEBRAIC(:,87) = strpad('tau_r1 in component airway21 (pascal)');
%     LEGEND_ALGEBRAIC(:,7) = strpad('u in component uv_type (pascal)');
%     LEGEND_ALGEBRAIC(:,1) = strpad('u_in in component uv_type (pascal)');
%     LEGEND_STATES(:,9) = strpad('u_v in component uv_type (pascal)');
%     LEGEND_CONSTANTS(:,2) = strpad('mu in component uv_type (Pas)');
%     LEGEND_CONSTANTS(:,3) = strpad('rho in component uv_type (kg_per_m3)');
%     LEGEND_CONSTANTS(:,4) = strpad('E in component uv_type (J_per_m3)');
%     LEGEND_STATES(:,10) = strpad('v in component uv_type1 (m3_per_s)');
%     LEGEND_STATES(:,11) = strpad('v_2 in component uv_type2 (m3_per_s)');
%     LEGEND_STATES(:,12) = strpad('v in component uv_type (m3_per_s)');
%     LEGEND_ALGEBRAIC(:,4) = strpad('R in component uv_type (Js_per_m6)');
%     LEGEND_ALGEBRAIC(:,6) = strpad('R_v in component uv_type (Js_per_m6)');
%     LEGEND_ALGEBRAIC(:,3) = strpad('C in component uv_type (m6_per_J)');
%     LEGEND_ALGEBRAIC(:,2) = strpad('I in component uv_type (Js2_per_m6)');
%     LEGEND_CONSTANTS(:,5) = strpad('l in component uv_type (meter)');
%     LEGEND_STATES(:,13) = strpad('r in component uv_type (meter)');
%     LEGEND_CONSTANTS(:,6) = strpad('Ri_sq_r1 in component uv_type (meter_sq)');
%     LEGEND_CONSTANTS(:,7) = strpad('rmax_sq_r1 in component uv_type (meter_sq)');
%     LEGEND_CONSTANTS(:,8) = strpad('N1_r1 in component uv_type (dimensionless)');
%     LEGEND_CONSTANTS(:,9) = strpad('N2_r1 in component uv_type (dimensionless)');
%     LEGEND_CONSTANTS(:,10) = strpad('P1_r1 in component uv_type (pascal)');
%     LEGEND_CONSTANTS(:,11) = strpad('P2_r1 in component uv_type (pascal)');
%     LEGEND_CONSTANTS(:,12) = strpad('rho1 in component uv_type (dimensionless)');
%     LEGEND_ALGEBRAIC(:,88) = strpad('rad_r1 in component uv_type (meter)');
%     LEGEND_CONSTANTS(:,13) = strpad('rmax_r1 in component uv_type (meter)');
%     LEGEND_CONSTANTS(:,14) = strpad('gamma in component uv_type (dimensionless)');
%     LEGEND_ALGEBRAIC(:,85) = strpad('Ptm_r1 in component uv_type (pascal)');
%     LEGEND_CONSTANTS(:,15) = strpad('h1 in component uv_type (meter)');
%     LEGEND_CONSTANTS(:,16) = strpad('R_ref in component uv_type (meter)');
%     LEGEND_ALGEBRAIC(:,81) = strpad('tau_r1 in component uv_type (pascal)');
%     LEGEND_CONSTANTS(:,17) = strpad('freq in component uv_type (per_s)');
%     LEGEND_CONSTANTS(:,18) = strpad('P_bar in component uv_type (pascal)');
%     LEGEND_CONSTANTS(:,19) = strpad('Paw_bar in component uv_type (pascal)');
%     LEGEND_CONSTANTS(:,20) = strpad('E1 in component uv_type (J_per_m3)');
%     LEGEND_CONSTANTS(:,144) = strpad('omega in component uv_type (dimensionless)');
%     LEGEND_CONSTANTS(:,21) = strpad('V_tlc in component uv_type (litre)');
%     LEGEND_ALGEBRAIC(:,62) = strpad('v1 in component uv_type (dimensionless)');
%     LEGEND_ALGEBRAIC(:,67) = strpad('x in component uv_type (dimensionless)');
%     LEGEND_ALGEBRAIC(:,5) = strpad('delP in component uv_type (pascal)');
%     LEGEND_CONSTANTS(:,22) = strpad('A in component uv_type (dimensionless)');
%     LEGEND_ALGEBRAIC(:,78) = strpad('P_sh_u in component uv_type (dimensionless)');
%     LEGEND_ALGEBRAIC(:,35) = strpad('P_sh in component airway (dimensionless)');
%     LEGEND_ALGEBRAIC(:,52) = strpad('P_sh in component airway1 (dimensionless)');
%     LEGEND_ALGEBRAIC(:,73) = strpad('P_sh in component airway2 (dimensionless)');
%     LEGEND_ALGEBRAIC(:,75) = strpad('P_sh in component airway21 (dimensionless)');
%     LEGEND_ALGEBRAIC(:,13) = strpad('u in component uv_type1 (pascal)');
%     LEGEND_STATES(:,14) = strpad('u_v in component uv_type1 (pascal)');
%     LEGEND_CONSTANTS(:,23) = strpad('mu in component uv_type1 (Pas)');
%     LEGEND_CONSTANTS(:,24) = strpad('rho in component uv_type1 (kg_per_m3)');
%     LEGEND_CONSTANTS(:,25) = strpad('E in component uv_type1 (J_per_m3)');
%     LEGEND_STATES(:,15) = strpad('v in component airway (m3_per_s)');
%     LEGEND_STATES(:,16) = strpad('v in component airway1 (m3_per_s)');
%     LEGEND_ALGEBRAIC(:,10) = strpad('R in component uv_type1 (Js_per_m6)');
%     LEGEND_ALGEBRAIC(:,12) = strpad('R_v in component uv_type1 (Js_per_m6)');
%     LEGEND_ALGEBRAIC(:,9) = strpad('C in component uv_type1 (m6_per_J)');
%     LEGEND_ALGEBRAIC(:,8) = strpad('I in component uv_type1 (Js2_per_m6)');
%     LEGEND_CONSTANTS(:,26) = strpad('l in component uv_type1 (meter)');
%     LEGEND_STATES(:,17) = strpad('r1 in component uv_type1 (meter)');
%     LEGEND_CONSTANTS(:,27) = strpad('Ri_sq_r1 in component uv_type1 (meter_sq)');
%     LEGEND_CONSTANTS(:,28) = strpad('rmax_sq_r1 in component uv_type1 (meter_sq)');
%     LEGEND_CONSTANTS(:,29) = strpad('N1_r1 in component uv_type1 (dimensionless)');
%     LEGEND_CONSTANTS(:,30) = strpad('N2_r1 in component uv_type1 (dimensionless)');
%     LEGEND_CONSTANTS(:,31) = strpad('P1_r1 in component uv_type1 (pascal)');
%     LEGEND_CONSTANTS(:,32) = strpad('P2_r1 in component uv_type1 (pascal)');
%     LEGEND_CONSTANTS(:,33) = strpad('rho1 in component uv_type1 (dimensionless)');
%     LEGEND_ALGEBRAIC(:,64) = strpad('rad_r1 in component uv_type1 (meter)');
%     LEGEND_CONSTANTS(:,34) = strpad('rmax_r1 in component uv_type1 (meter)');
%     LEGEND_CONSTANTS(:,35) = strpad('gamma in component uv_type1 (dimensionless)');
%     LEGEND_ALGEBRAIC(:,60) = strpad('Ptm_r1 in component uv_type1 (pascal)');
%     LEGEND_CONSTANTS(:,36) = strpad('h1 in component uv_type1 (meter)');
%     LEGEND_CONSTANTS(:,37) = strpad('R_ref in component uv_type1 (meter)');
%     LEGEND_ALGEBRAIC(:,58) = strpad('tau_r1 in component uv_type1 (pascal)');
%     LEGEND_CONSTANTS(:,38) = strpad('E1 in component uv_type1 (J_per_m3)');
%     LEGEND_CONSTANTS(:,39) = strpad('V_tlc in component uv_type1 (litre)');
%     LEGEND_ALGEBRAIC(:,43) = strpad('v1 in component uv_type1 (dimensionless)');
%     LEGEND_ALGEBRAIC(:,47) = strpad('x in component uv_type1 (dimensionless)');
%     LEGEND_ALGEBRAIC(:,11) = strpad('delP1 in component uv_type1 (pascal)');
%     LEGEND_CONSTANTS(:,40) = strpad('A in component uv_type1 (dimensionless)');
%     LEGEND_ALGEBRAIC(:,55) = strpad('P_sh1 in component uv_type1 (dimensionless)');
%     LEGEND_ALGEBRAIC(:,17) = strpad('delP_2 in component uv_type2 (pascal)');
%     LEGEND_STATES(:,18) = strpad('r2 in component uv_type2 (meter)');
%     LEGEND_ALGEBRAIC(:,19) = strpad('u in component uv_type2 (pascal)');
%     LEGEND_STATES(:,19) = strpad('u_v in component uv_type2 (pascal)');
%     LEGEND_CONSTANTS(:,41) = strpad('mu in component uv_type2 (Pas)');
%     LEGEND_CONSTANTS(:,42) = strpad('rho in component uv_type2 (kg_per_m3)');
%     LEGEND_CONSTANTS(:,43) = strpad('E in component uv_type2 (J_per_m3)');
%     LEGEND_STATES(:,20) = strpad('v in component airway2 (m3_per_s)');
%     LEGEND_STATES(:,21) = strpad('v in component airway21 (m3_per_s)');
%     LEGEND_ALGEBRAIC(:,16) = strpad('R in component uv_type2 (Js_per_m6)');
%     LEGEND_ALGEBRAIC(:,18) = strpad('R_v in component uv_type2 (Js_per_m6)');
%     LEGEND_ALGEBRAIC(:,15) = strpad('C in component uv_type2 (m6_per_J)');
%     LEGEND_ALGEBRAIC(:,14) = strpad('I in component uv_type2 (Js2_per_m6)');
%     LEGEND_CONSTANTS(:,44) = strpad('l in component uv_type2 (meter)');
%     LEGEND_CONSTANTS(:,45) = strpad('Ri_sq_r1 in component uv_type2 (meter_sq)');
%     LEGEND_CONSTANTS(:,46) = strpad('rmax_sq_r1 in component uv_type2 (meter)');
%     LEGEND_CONSTANTS(:,47) = strpad('N1_r1 in component uv_type2 (dimensionless)');
%     LEGEND_CONSTANTS(:,48) = strpad('N2_r1 in component uv_type2 (dimensionless)');
%     LEGEND_CONSTANTS(:,49) = strpad('P1_r1 in component uv_type2 (pascal)');
%     LEGEND_CONSTANTS(:,50) = strpad('P2_r1 in component uv_type2 (pascal)');
%     LEGEND_CONSTANTS(:,51) = strpad('rho1 in component uv_type2 (dimensionless)');
%     LEGEND_ALGEBRAIC(:,89) = strpad('rad_r1 in component uv_type2 (meter)');
%     LEGEND_CONSTANTS(:,52) = strpad('rmax_r1 in component uv_type2 (meter)');
%     LEGEND_CONSTANTS(:,53) = strpad('gamma in component uv_type2 (dimensionless)');
%     LEGEND_ALGEBRAIC(:,86) = strpad('Ptm_r1 in component uv_type2 (pascal)');
%     LEGEND_CONSTANTS(:,54) = strpad('h1 in component uv_type2 (meter)');
%     LEGEND_CONSTANTS(:,55) = strpad('R_ref in component uv_type2 (meter)');
%     LEGEND_ALGEBRAIC(:,82) = strpad('tau_r1 in component uv_type2 (pascal)');
%     LEGEND_CONSTANTS(:,56) = strpad('E1 in component uv_type2 (J_per_m3)');
%     LEGEND_CONSTANTS(:,57) = strpad('V_tlc in component uv_type2 (litre)');
%     LEGEND_ALGEBRAIC(:,90) = strpad('v1 in component uv_type2 (dimensionless)');
%     LEGEND_ALGEBRAIC(:,94) = strpad('x in component uv_type2 (dimensionless)');
%     LEGEND_CONSTANTS(:,58) = strpad('A in component uv_type2 (dimensionless)');
%     LEGEND_ALGEBRAIC(:,79) = strpad('P_sh2 in component uv_type2 (dimensionless)');
%     LEGEND_ALGEBRAIC(:,30) = strpad('u in component airway (pascal)');
%     LEGEND_STATES(:,22) = strpad('u_v in component airway (pascal)');
%     LEGEND_CONSTANTS(:,59) = strpad('mu in component airway (Pas)');
%     LEGEND_CONSTANTS(:,60) = strpad('rho in component airway (kg_per_m3)');
%     LEGEND_CONSTANTS(:,61) = strpad('E in component airway (J_per_m3)');
%     LEGEND_ALGEBRAIC(:,22) = strpad('R in component airway (Js_per_m6)');
%     LEGEND_ALGEBRAIC(:,27) = strpad('R_v in component airway (Js_per_m6)');
%     LEGEND_ALGEBRAIC(:,21) = strpad('C in component airway (m6_per_J)');
%     LEGEND_ALGEBRAIC(:,20) = strpad('I in component airway (Js2_per_m6)');
%     LEGEND_CONSTANTS(:,62) = strpad('l in component airway (meter)');
%     LEGEND_CONSTANTS(:,63) = strpad('Ri_sq_r1 in component airway (meter_sq)');
%     LEGEND_CONSTANTS(:,64) = strpad('rmax_sq_r1 in component airway (meter_sq)');
%     LEGEND_CONSTANTS(:,65) = strpad('N1_r1 in component airway (dimensionless)');
%     LEGEND_CONSTANTS(:,66) = strpad('N2_r1 in component airway (dimensionless)');
%     LEGEND_CONSTANTS(:,67) = strpad('P1_r1 in component airway (pascal)');
%     LEGEND_CONSTANTS(:,68) = strpad('P2_r1 in component airway (pascal)');
%     LEGEND_CONSTANTS(:,69) = strpad('rho1 in component airway (dimensionless)');
%     LEGEND_ALGEBRAIC(:,41) = strpad('rad_r1 in component airway (meter)');
%     LEGEND_CONSTANTS(:,70) = strpad('rmax_r1 in component airway (meter)');
%     LEGEND_CONSTANTS(:,71) = strpad('gamma in component airway (dimensionless)');
%     LEGEND_CONSTANTS(:,72) = strpad('h1 in component airway (meter)');
%     LEGEND_CONSTANTS(:,73) = strpad('R_ref in component airway (meter)');
%     LEGEND_CONSTANTS(:,74) = strpad('freq in component airway (per_s)');
%     LEGEND_CONSTANTS(:,75) = strpad('P_bar in component airway (pascal)');
%     LEGEND_CONSTANTS(:,76) = strpad('Paw_bar in component airway (pascal)');
%     LEGEND_CONSTANTS(:,77) = strpad('E1 in component airway (J_per_m3)');
%     LEGEND_ALGEBRAIC(:,23) = strpad('PA_bar in component airway (pascal)');
%     LEGEND_ALGEBRAIC(:,24) = strpad('alpha in component airway (second)');
%     LEGEND_CONSTANTS(:,145) = strpad('omega in component airway (dimensionless)');
%     LEGEND_CONSTANTS(:,78) = strpad('V_tlc in component airway (litre)');
%     LEGEND_ALGEBRAIC(:,28) = strpad('v1 in component airway (dimensionless)');
%     LEGEND_ALGEBRAIC(:,31) = strpad('x in component airway (dimensionless)');
%     LEGEND_ALGEBRAIC(:,26) = strpad('delP in component airway (pascal)');
%     LEGEND_ALGEBRAIC(:,34) = strpad('delP_2 in component airway1 (pascal)');
%     LEGEND_CONSTANTS(:,79) = strpad('A in component airway (dimensionless)');
%     LEGEND_ALGEBRAIC(:,48) = strpad('u in component airway1 (pascal)');
%     LEGEND_STATES(:,23) = strpad('u_v in component airway1 (pascal)');
%     LEGEND_CONSTANTS(:,80) = strpad('mu in component airway1 (Pas)');
%     LEGEND_CONSTANTS(:,81) = strpad('rho in component airway1 (kg_per_m3)');
%     LEGEND_CONSTANTS(:,82) = strpad('E in component airway1 (J_per_m3)');
%     LEGEND_ALGEBRAIC(:,33) = strpad('R in component airway1 (Js_per_m6)');
%     LEGEND_ALGEBRAIC(:,44) = strpad('R_v in component airway1 (Js_per_m6)');
%     LEGEND_ALGEBRAIC(:,32) = strpad('C in component airway1 (m6_per_J)');
%     LEGEND_ALGEBRAIC(:,29) = strpad('I in component airway1 (Js2_per_m6)');
%     LEGEND_CONSTANTS(:,83) = strpad('l in component airway1 (meter)');
%     LEGEND_CONSTANTS(:,84) = strpad('Ri_sq_r1 in component airway1 (meter_sq)');
%     LEGEND_CONSTANTS(:,85) = strpad('rmax_sq_r1 in component airway1 (meter_sq)');
%     LEGEND_CONSTANTS(:,86) = strpad('N1_r1 in component airway1 (dimensionless)');
%     LEGEND_CONSTANTS(:,87) = strpad('N2_r1 in component airway1 (dimensionless)');
%     LEGEND_CONSTANTS(:,88) = strpad('P1_r1 in component airway1 (pascal)');
%     LEGEND_CONSTANTS(:,89) = strpad('P2_r1 in component airway1 (pascal)');
%     LEGEND_CONSTANTS(:,90) = strpad('rho1 in component airway1 (dimensionless)');
%     LEGEND_ALGEBRAIC(:,61) = strpad('rad_r1 in component airway1 (meter)');
%     LEGEND_CONSTANTS(:,91) = strpad('rmax_r1 in component airway1 (meter)');
%     LEGEND_CONSTANTS(:,92) = strpad('gamma in component airway1 (dimensionless)');
%     LEGEND_CONSTANTS(:,93) = strpad('h1 in component airway1 (meter)');
%     LEGEND_CONSTANTS(:,94) = strpad('R_ref in component airway1 (meter)');
%     LEGEND_CONSTANTS(:,95) = strpad('freq in component airway1 (per_s)');
%     LEGEND_CONSTANTS(:,96) = strpad('P_bar in component airway1 (pascal)');
%     LEGEND_CONSTANTS(:,97) = strpad('Paw_bar in component airway1 (pascal)');
%     LEGEND_CONSTANTS(:,98) = strpad('E1 in component airway1 (J_per_m3)');
%     LEGEND_ALGEBRAIC(:,37) = strpad('PA_bar in component airway1 (pascal)');
%     LEGEND_ALGEBRAIC(:,39) = strpad('alpha in component airway1 (second)');
%     LEGEND_CONSTANTS(:,146) = strpad('omega in component airway1 (dimensionless)');
%     LEGEND_CONSTANTS(:,99) = strpad('V_tlc in component airway1 (litre)');
%     LEGEND_ALGEBRAIC(:,45) = strpad('v1 in component airway1 (dimensionless)');
%     LEGEND_ALGEBRAIC(:,49) = strpad('x in component airway1 (dimensionless)');
%     LEGEND_CONSTANTS(:,100) = strpad('A in component airway1 (dimensionless)');
%     LEGEND_ALGEBRAIC(:,51) = strpad('delP_3 in component airway2 (pascal)');
%     LEGEND_ALGEBRAIC(:,69) = strpad('u in component airway2 (pascal)');
%     LEGEND_STATES(:,24) = strpad('u_v in component airway2 (pascal)');
%     LEGEND_CONSTANTS(:,101) = strpad('mu in component airway2 (Pas)');
%     LEGEND_CONSTANTS(:,102) = strpad('rho in component airway2 (kg_per_m3)');
%     LEGEND_CONSTANTS(:,103) = strpad('E in component airway2 (J_per_m3)');
%     LEGEND_ALGEBRAIC(:,50) = strpad('R in component airway2 (Js_per_m6)');
%     LEGEND_ALGEBRAIC(:,65) = strpad('R_v in component airway2 (Js_per_m6)');
%     LEGEND_ALGEBRAIC(:,46) = strpad('C in component airway2 (m6_per_J)');
%     LEGEND_ALGEBRAIC(:,42) = strpad('I in component airway2 (Js2_per_m6)');
%     LEGEND_CONSTANTS(:,104) = strpad('l in component airway2 (meter)');
%     LEGEND_CONSTANTS(:,105) = strpad('Ri_sq_r1 in component airway2 (meter_sq)');
%     LEGEND_CONSTANTS(:,106) = strpad('rmax_sq_r1 in component airway2 (meter_sq)');
%     LEGEND_CONSTANTS(:,107) = strpad('N1_r1 in component airway2 (dimensionless)');
%     LEGEND_CONSTANTS(:,108) = strpad('N2_r1 in component airway2 (dimensionless)');
%     LEGEND_CONSTANTS(:,109) = strpad('P1_r1 in component airway2 (pascal)');
%     LEGEND_CONSTANTS(:,110) = strpad('P2_r1 in component airway2 (pascal)');
%     LEGEND_CONSTANTS(:,111) = strpad('rho1 in component airway2 (dimensionless)');
%     LEGEND_ALGEBRAIC(:,83) = strpad('rad_r1 in component airway2 (meter)');
%     LEGEND_CONSTANTS(:,112) = strpad('rmax_r1 in component airway2 (meter)');
%     LEGEND_CONSTANTS(:,113) = strpad('gamma in component airway2 (dimensionless)');
%     LEGEND_CONSTANTS(:,114) = strpad('h1 in component airway2 (meter)');
%     LEGEND_CONSTANTS(:,115) = strpad('R_ref in component airway2 (meter)');
%     LEGEND_CONSTANTS(:,116) = strpad('freq in component airway2 (per_s)');
%     LEGEND_CONSTANTS(:,117) = strpad('P_bar in component airway2 (pascal)');
%     LEGEND_CONSTANTS(:,118) = strpad('Paw_bar in component airway2 (pascal)');
%     LEGEND_CONSTANTS(:,119) = strpad('E1 in component airway2 (J_per_m3)');
%     LEGEND_ALGEBRAIC(:,54) = strpad('PA_bar in component airway2 (pascal)');
%     LEGEND_ALGEBRAIC(:,57) = strpad('alpha in component airway2 (second)');
%     LEGEND_CONSTANTS(:,147) = strpad('omega in component airway2 (dimensionless)');
%     LEGEND_CONSTANTS(:,120) = strpad('V_tlc in component airway2 (litre)');
%     LEGEND_ALGEBRAIC(:,66) = strpad('v1 in component airway2 (dimensionless)');
%     LEGEND_ALGEBRAIC(:,70) = strpad('x in component airway2 (dimensionless)');
%     LEGEND_CONSTANTS(:,121) = strpad('A in component airway2 (dimensionless)');
%     LEGEND_ALGEBRAIC(:,72) = strpad('delP_4 in component airway21 (pascal)');
%     LEGEND_ALGEBRAIC(:,95) = strpad('u in component airway21 (pascal)');
%     LEGEND_STATES(:,25) = strpad('u_v in component airway21 (pascal)');
%     LEGEND_CONSTANTS(:,122) = strpad('mu in component airway21 (Pas)');
%     LEGEND_CONSTANTS(:,123) = strpad('rho in component airway21 (kg_per_m3)');
%     LEGEND_CONSTANTS(:,124) = strpad('E in component airway21 (J_per_m3)');
%     LEGEND_ALGEBRAIC(:,71) = strpad('R in component airway21 (Js_per_m6)');
%     LEGEND_ALGEBRAIC(:,91) = strpad('R_v in component airway21 (Js_per_m6)');
%     LEGEND_ALGEBRAIC(:,68) = strpad('C in component airway21 (m6_per_J)');
%     LEGEND_ALGEBRAIC(:,63) = strpad('I in component airway21 (Js2_per_m6)');
%     LEGEND_CONSTANTS(:,125) = strpad('l in component airway21 (meter)');
%     LEGEND_CONSTANTS(:,126) = strpad('Ri_sq_r1 in component airway21 (meter_sq)');
%     LEGEND_CONSTANTS(:,127) = strpad('rmax_sq_r1 in component airway21 (meter_sq)');
%     LEGEND_CONSTANTS(:,128) = strpad('N1_r1 in component airway21 (dimensionless)');
%     LEGEND_CONSTANTS(:,129) = strpad('N2_r1 in component airway21 (dimensionless)');
%     LEGEND_CONSTANTS(:,130) = strpad('P1_r1 in component airway21 (pascal)');
%     LEGEND_CONSTANTS(:,131) = strpad('P2_r1 in component airway21 (pascal)');
%     LEGEND_CONSTANTS(:,132) = strpad('rho1 in component airway21 (dimensionless)');
%     LEGEND_ALGEBRAIC(:,97) = strpad('rad_r1 in component airway21 (meter)');
%     LEGEND_CONSTANTS(:,133) = strpad('rmax_r1 in component airway21 (meter)');
%     LEGEND_CONSTANTS(:,134) = strpad('gamma in component airway21 (dimensionless)');
%     LEGEND_CONSTANTS(:,135) = strpad('h1 in component airway21 (meter)');
%     LEGEND_CONSTANTS(:,136) = strpad('R_ref in component airway21 (meter)');
%     LEGEND_CONSTANTS(:,137) = strpad('freq in component airway21 (per_s)');
%     LEGEND_CONSTANTS(:,138) = strpad('P_bar in component airway21 (pascal)');
%     LEGEND_CONSTANTS(:,139) = strpad('Paw_bar in component airway21 (pascal)');
%     LEGEND_CONSTANTS(:,140) = strpad('E1 in component airway21 (J_per_m3)');
%     LEGEND_ALGEBRAIC(:,77) = strpad('PA_bar in component airway21 (pascal)');
%     LEGEND_ALGEBRAIC(:,80) = strpad('alpha in component airway21 (second)');
%     LEGEND_CONSTANTS(:,148) = strpad('omega in component airway21 (dimensionless)');
%     LEGEND_CONSTANTS(:,141) = strpad('V_tlc in component airway21 (litre)');
%     LEGEND_ALGEBRAIC(:,92) = strpad('v1 in component airway21 (dimensionless)');
%     LEGEND_ALGEBRAIC(:,96) = strpad('x in component airway21 (dimensionless)');
%     LEGEND_CONSTANTS(:,142) = strpad('A in component airway21 (dimensionless)');
%     LEGEND_RATES(:,12) = strpad('d/dt v in component uv_type (m3_per_s)');
%     LEGEND_RATES(:,9) = strpad('d/dt u_v in component uv_type (pascal)');
%     LEGEND_RATES(:,13) = strpad('d/dt r in component uv_type (meter)');
%     LEGEND_RATES(:,10) = strpad('d/dt v in component uv_type1 (m3_per_s)');
%     LEGEND_RATES(:,14) = strpad('d/dt u_v in component uv_type1 (pascal)');
%     LEGEND_RATES(:,17) = strpad('d/dt r1 in component uv_type1 (meter)');
%     LEGEND_RATES(:,11) = strpad('d/dt v_2 in component uv_type2 (m3_per_s)');
%     LEGEND_RATES(:,19) = strpad('d/dt u_v in component uv_type2 (pascal)');
%     LEGEND_RATES(:,18) = strpad('d/dt r2 in component uv_type2 (meter)');
%     LEGEND_RATES(:,15) = strpad('d/dt v in component airway (m3_per_s)');
%     LEGEND_RATES(:,22) = strpad('d/dt u_v in component airway (pascal)');
%     LEGEND_RATES(:,5) = strpad('d/dt v_d in component airway (m3_per_s)');
%     LEGEND_RATES(:,1) = strpad('d/dt r1 in component airway (meter)');
%     LEGEND_RATES(:,16) = strpad('d/dt v in component airway1 (m3_per_s)');
%     LEGEND_RATES(:,23) = strpad('d/dt u_v in component airway1 (pascal)');
%     LEGEND_RATES(:,6) = strpad('d/dt v_d in component airway1 (m3_per_s)');
%     LEGEND_RATES(:,2) = strpad('d/dt r1 in component airway1 (meter)');
%     LEGEND_RATES(:,20) = strpad('d/dt v in component airway2 (m3_per_s)');
%     LEGEND_RATES(:,24) = strpad('d/dt u_v in component airway2 (pascal)');
%     LEGEND_RATES(:,7) = strpad('d/dt v_d in component airway2 (m3_per_s)');
%     LEGEND_RATES(:,3) = strpad('d/dt r1 in component airway2 (meter)');
%     LEGEND_RATES(:,21) = strpad('d/dt v in component airway21 (m3_per_s)');
%     LEGEND_RATES(:,25) = strpad('d/dt u_v in component airway21 (pascal)');
%     LEGEND_RATES(:,8) = strpad('d/dt v_d in component airway21 (m3_per_s)');
%     LEGEND_RATES(:,4) = strpad('d/dt r1 in component airway21 (meter)');
%     LEGEND_STATES  = LEGEND_STATES';
%     LEGEND_ALGEBRAIC = LEGEND_ALGEBRAIC';
%     LEGEND_RATES = LEGEND_RATES';
%     LEGEND_CONSTANTS = LEGEND_CONSTANTS';
% end

function [STATES, CONSTANTS] = initConsts()
    VOI = 0; CONSTANTS = []; STATES = []; ALGEBRAIC = [];
    CONSTANTS(:,1) = 20;
    STATES(:,1) = 0.000296;
    STATES(:,2) = 0.000296;
    STATES(:,3) = 0.000296;
    STATES(:,4) = 0.000296;
    STATES(:,5) = 0;
    STATES(:,6) = 0;
    STATES(:,7) = 0;
    STATES(:,8) = 0;
    STATES(:,9) = 0;
    CONSTANTS(:,2) = 1.81e-5;
    CONSTANTS(:,3) = 1.225;
    CONSTANTS(:,4) = 0.35e6;
    STATES(:,10) = 0;
    STATES(:,11) = 0;
    STATES(:,12) = 0;
    CONSTANTS(:,5) = 0.002056;
    STATES(:,13) = 0.0003370;
    CONSTANTS(:,6) = 5.329e-9;
    CONSTANTS(:,7) = 1.13569e-7;
    CONSTANTS(:,8) = 1;
    CONSTANTS(:,9) = 7.185;
    CONSTANTS(:,10) = 19.475;
    CONSTANTS(:,11) = -2842.145466;
    CONSTANTS(:,12) = 1;
    CONSTANTS(:,13) = 0.000337;
    CONSTANTS(:,14) = 25;
    CONSTANTS(:,15) = 0.0009732;
    CONSTANTS(:,16) = 0.0002792;
    CONSTANTS(:,17) = 0.33;
    CONSTANTS(:,18) = 490.3;
    CONSTANTS(:,19) = 490;
    CONSTANTS(:,20) = 0.25;
    CONSTANTS(:,21) = 0.0001;
    CONSTANTS(:,22) = 5e2;
    STATES(:,14) = 0;
    CONSTANTS(:,23) = 1.81e-5;
    CONSTANTS(:,24) = 1.225;
    CONSTANTS(:,25) = 0.35e6;
    STATES(:,15) = 0;
    STATES(:,16) = 0;
    CONSTANTS(:,26) = 0.001878;
    STATES(:,17) = 0.000318;
    CONSTANTS(:,27) = 4.225e-9;
    CONSTANTS(:,28) = 1.011e-7;
    CONSTANTS(:,29) = 1;
    CONSTANTS(:,30) = 7;
    CONSTANTS(:,31) = 17.342;
    CONSTANTS(:,32) = -2784.131883;
    CONSTANTS(:,33) = 1;
    CONSTANTS(:,34) = 0.000318;
    CONSTANTS(:,35) = 25;
    CONSTANTS(:,36) = 0.0009732;
    CONSTANTS(:,37) = 0.0002792;
    CONSTANTS(:,38) = 0.25;
    CONSTANTS(:,39) = 0.0001;
    CONSTANTS(:,40) = 5e2;
    STATES(:,18) = 0.000318;
    STATES(:,19) = 0;
    CONSTANTS(:,41) = 1.81e-5;
    CONSTANTS(:,42) = 1.225;
    CONSTANTS(:,43) = 0.35e6;
    STATES(:,20) = 0;
    STATES(:,21) = 0;
    CONSTANTS(:,44) = 0.001878;
    CONSTANTS(:,45) = 4.225e-9;
    CONSTANTS(:,46) = 1.011e-7;
    CONSTANTS(:,47) = 1;
    CONSTANTS(:,48) = 7;
    CONSTANTS(:,49) = 17.342;
    CONSTANTS(:,50) = -2784.131883;
    CONSTANTS(:,51) = 1;
    CONSTANTS(:,52) = 0.000318;
    CONSTANTS(:,53) = 25;
    CONSTANTS(:,54) = 0.0009732;
    CONSTANTS(:,55) = 0.0002792;
    CONSTANTS(:,56) = 0.25;
    CONSTANTS(:,57) = 0.0001;
    CONSTANTS(:,58) = 5e2;
    STATES(:,22) = 0;
    CONSTANTS(:,59) = 1.81e-5;
    CONSTANTS(:,60) = 1.225;
    CONSTANTS(:,61) = 0.35e6;
    CONSTANTS(:,62) = 0.0017;
    CONSTANTS(:,63) = 3.364E-09;
    CONSTANTS(:,64) = 8.7616E-08;
    CONSTANTS(:,65) = 1;
    CONSTANTS(:,66) = 7;
    CONSTANTS(:,67) = 15.728;
    CONSTANTS(:,68) = -2757.374611;
    CONSTANTS(:,69) = 1;
    CONSTANTS(:,70) = 0.000296;
    CONSTANTS(:,71) = 25;
    CONSTANTS(:,72) = 0.0010873;
    CONSTANTS(:,73) = 0.0002792;
    CONSTANTS(:,74) = 0.33;
    CONSTANTS(:,75) = 490.3;
    CONSTANTS(:,76) = 490;
    CONSTANTS(:,77) = 0.25;
    CONSTANTS(:,78) = 0.0001;
    CONSTANTS(:,79) = 3e15;
    STATES(:,23) = 0;
    CONSTANTS(:,80) = 1.81e-5;
    CONSTANTS(:,81) = 1.225;
    CONSTANTS(:,82) = 0.35e6;
    CONSTANTS(:,83) = 0.0017;
    CONSTANTS(:,84) = 3.364e-9;
    CONSTANTS(:,85) = 8.7616e-8;
    CONSTANTS(:,86) = 1;
    CONSTANTS(:,87) = 7;
    CONSTANTS(:,88) = 15.728;
    CONSTANTS(:,89) = -2757.374611;
    CONSTANTS(:,90) = 1;
    CONSTANTS(:,91) = 0.000296;
    CONSTANTS(:,92) = 25;
    CONSTANTS(:,93) = 0.0010873;
    CONSTANTS(:,94) = 0.0002792;
    CONSTANTS(:,95) = 0.33;
    CONSTANTS(:,96) = 490.3;
    CONSTANTS(:,97) = 490;
    CONSTANTS(:,98) = 0.25;
    CONSTANTS(:,99) = 0.0001;
    CONSTANTS(:,100) = 3e15;
    STATES(:,24) = 0;
    CONSTANTS(:,101) = 1.81e-5;
    CONSTANTS(:,102) = 1.225;
    CONSTANTS(:,103) = 0.35e6;
    CONSTANTS(:,104) = 0.0017;
    CONSTANTS(:,105) = 3.364e-9;
    CONSTANTS(:,106) = 8.7616e-8;
    CONSTANTS(:,107) = 1;
    CONSTANTS(:,108) = 7;
    CONSTANTS(:,109) = 15.728;
    CONSTANTS(:,110) = -2757.374611;
    CONSTANTS(:,111) = 1;
    CONSTANTS(:,112) = 0.00028;
    CONSTANTS(:,113) = 25;
    CONSTANTS(:,114) = 0.0010873;
    CONSTANTS(:,115) = 0.0002792;
    CONSTANTS(:,116) = 0.33;
    CONSTANTS(:,117) = 490.3;
    CONSTANTS(:,118) = 490;
    CONSTANTS(:,119) = 0.25;
    CONSTANTS(:,120) = 0.0001;
    CONSTANTS(:,121) = 3e15;
    STATES(:,25) = 0;
    CONSTANTS(:,122) = 1.81e-5;
    CONSTANTS(:,123) = 1.225;
    CONSTANTS(:,124) = 0.35e6;
    CONSTANTS(:,125) = 0.0017;
    CONSTANTS(:,126) = 3.364e-9;
    CONSTANTS(:,127) = 8.7616e-8;
    CONSTANTS(:,128) = 1;
    CONSTANTS(:,129) = 7;
    CONSTANTS(:,130) = 15.728;
    CONSTANTS(:,131) = -2757.374611;
    CONSTANTS(:,132) = 1;
    CONSTANTS(:,133) = 0.00028;
    CONSTANTS(:,134) = 25;
    CONSTANTS(:,135) = 0.0010873;
    CONSTANTS(:,136) = 0.0002792;
    CONSTANTS(:,137) = 0.33;
    CONSTANTS(:,138) = 490.3;
    CONSTANTS(:,139) = 490;
    CONSTANTS(:,140) = 0.25;
    CONSTANTS(:,141) = 0.0001;
    CONSTANTS(:,142) = 3e15;
    CONSTANTS(:,143) = CONSTANTS(:,1);
    CONSTANTS(:,144) =  2.00000.* pi.*CONSTANTS(:,17);
    CONSTANTS(:,145) =  2.00000.* pi.*CONSTANTS(:,74);
    CONSTANTS(:,146) =  2.00000.* pi.*CONSTANTS(:,95);
    CONSTANTS(:,147) =  2.00000.* pi.*CONSTANTS(:,116);
    CONSTANTS(:,148) =  2.00000.* pi.*CONSTANTS(:,137);
    if (isempty(STATES)), warning('Initial values for states not set'); end
end

function [RATES, ALGEBRAIC] = computeRates(VOI, STATES, CONSTANTS)
    global algebraicVariableCount;
    statesSize = size(STATES);
    statesColumnCount = statesSize(2);
    if ( statesColumnCount == 1)
        STATES = STATES';
        ALGEBRAIC = zeros(1, algebraicVariableCount);
        utilOnes = 1;
    else
        statesRowCount = statesSize(1);
        ALGEBRAIC = zeros(statesRowCount, algebraicVariableCount);
        RATES = zeros(statesRowCount, statesColumnCount);
        utilOnes = ones(statesRowCount, 1);
    end
    ALGEBRAIC(:,3) = ( 2.00000.* pi.*power(STATES(:,13), 3.00000).*CONSTANTS(:,5))./( CONSTANTS(:,4).*CONSTANTS(:,15));
    RATES(:,9) = ((STATES(:,12) - STATES(:,10)) - STATES(:,11))./ALGEBRAIC(:,3);
    ALGEBRAIC(:,6) = 0.0100000./ALGEBRAIC(:,3);
    ALGEBRAIC(:,7) = STATES(:,9)+ ALGEBRAIC(:,6).*((STATES(:,12) - STATES(:,10)) - STATES(:,11));
    ALGEBRAIC(:,1) = CONSTANTS(:,18)+ CONSTANTS(:,19).* sin( CONSTANTS(:,144).*VOI);
    ALGEBRAIC(:,4) = ( 8.00000.*CONSTANTS(:,2).*CONSTANTS(:,5))./(  pi.*power(STATES(:,13), 4.00000));
    ALGEBRAIC(:,2) = ( CONSTANTS(:,3).*CONSTANTS(:,5))./(  pi.*power(STATES(:,13), 2.00000));
    RATES(:,12) = ((ALGEBRAIC(:,1) - ALGEBRAIC(:,7)) -  ALGEBRAIC(:,4).*STATES(:,12))./ALGEBRAIC(:,2);
    ALGEBRAIC(:,9) = ( 2.00000.* pi.*power(STATES(:,17), 3.00000).*CONSTANTS(:,26))./( CONSTANTS(:,25).*CONSTANTS(:,36));
    RATES(:,14) = ((STATES(:,10) - STATES(:,15)) - STATES(:,16))./ALGEBRAIC(:,9);
    ALGEBRAIC(:,12) = 0.0100000./ALGEBRAIC(:,9);
    ALGEBRAIC(:,13) = STATES(:,14)+ ALGEBRAIC(:,12).*((STATES(:,10) - STATES(:,15)) - STATES(:,16));
    ALGEBRAIC(:,10) = ( 8.00000.*CONSTANTS(:,23).*CONSTANTS(:,26))./(  pi.*power(STATES(:,17), 4.00000));
    ALGEBRAIC(:,8) = ( CONSTANTS(:,24).*CONSTANTS(:,26))./(  pi.*power(STATES(:,17), 2.00000));
    RATES(:,10) = ((ALGEBRAIC(:,7) - ALGEBRAIC(:,13)) -  ALGEBRAIC(:,10).*STATES(:,10))./ALGEBRAIC(:,8);
    ALGEBRAIC(:,15) = ( 2.00000.* pi.*power(STATES(:,18), 3.00000).*CONSTANTS(:,44))./( CONSTANTS(:,43).*CONSTANTS(:,54));
    RATES(:,19) = ((STATES(:,11) - STATES(:,20)) - STATES(:,21))./ALGEBRAIC(:,15);
    ALGEBRAIC(:,18) = 0.0100000./ALGEBRAIC(:,15);
    ALGEBRAIC(:,19) = STATES(:,19)+ ALGEBRAIC(:,18).*((STATES(:,11) - STATES(:,20)) - STATES(:,21));
    ALGEBRAIC(:,16) = ( 8.00000.*CONSTANTS(:,41).*CONSTANTS(:,44))./(  pi.*power(STATES(:,18), 4.00000));
    ALGEBRAIC(:,14) = ( CONSTANTS(:,42).*CONSTANTS(:,44))./(  pi.*power(STATES(:,18), 2.00000));
    RATES(:,11) = ((ALGEBRAIC(:,7) - ALGEBRAIC(:,19)) -  ALGEBRAIC(:,16).*STATES(:,11))./ALGEBRAIC(:,14);
    ALGEBRAIC(:,21) = ( 2.00000.* pi.*power(STATES(:,1), 3.00000).*CONSTANTS(:,62))./( CONSTANTS(:,61).*CONSTANTS(:,72));
    RATES(:,22) = (STATES(:,15) - STATES(:,5))./ALGEBRAIC(:,21);
    ALGEBRAIC(:,27) = 0.0100000./ALGEBRAIC(:,21);
    ALGEBRAIC(:,30) = STATES(:,22)+ ALGEBRAIC(:,27).*(STATES(:,15) - STATES(:,5));
    ALGEBRAIC(:,22) = ( 8.00000.*CONSTANTS(:,59).*CONSTANTS(:,62))./(  pi.*power(STATES(:,1), 4.00000));
    ALGEBRAIC(:,20) = ( CONSTANTS(:,60).*CONSTANTS(:,62))./(  pi.*power(STATES(:,1), 2.00000));
    RATES(:,15) = ((ALGEBRAIC(:,13) - ALGEBRAIC(:,30)) -  (ALGEBRAIC(:,22)./2.00000).*STATES(:,15))./(ALGEBRAIC(:,20)./2.00000);
    ALGEBRAIC(:,23) = ( CONSTANTS(:,76).*CONSTANTS(:,77))./power((power(CONSTANTS(:,77), 2.00000)+power( CONSTANTS(:,145).*ALGEBRAIC(:,22), 2.00000)), 1.0 ./ 2);
    ALGEBRAIC(:,24) = atan(( CONSTANTS(:,145).*ALGEBRAIC(:,22))./CONSTANTS(:,77));
    ALGEBRAIC(:,25) = CONSTANTS(:,75)+ ALGEBRAIC(:,23).* sin( CONSTANTS(:,145).*VOI - ALGEBRAIC(:,24));
    RATES(:,5) = ((ALGEBRAIC(:,30) - ALGEBRAIC(:,25)) -  (ALGEBRAIC(:,22)./2.00000).*STATES(:,5))./(ALGEBRAIC(:,20)./2.00000);
    ALGEBRAIC(:,32) = ( 2.00000.* pi.*power(STATES(:,2), 3.00000).*CONSTANTS(:,83))./( CONSTANTS(:,82).*CONSTANTS(:,93));
    RATES(:,23) = (STATES(:,16) - STATES(:,6))./ALGEBRAIC(:,32);
    ALGEBRAIC(:,26) =  STATES(:,15).*ALGEBRAIC(:,22);
    ALGEBRAIC(:,33) = ( 8.00000.*CONSTANTS(:,80).*CONSTANTS(:,83))./(  pi.*power(STATES(:,2), 4.00000));
    ALGEBRAIC(:,34) =  STATES(:,16).*ALGEBRAIC(:,33);
    ALGEBRAIC(:,35) = abs( (CONSTANTS(:,79)./3.00000).*( ALGEBRAIC(:,26).*power(STATES(:,1), 4.00000)+ ALGEBRAIC(:,34).*power(STATES(:,2), 4.00000)))./2.00000;
    ALGEBRAIC(:,36) =  2.00000.*ALGEBRAIC(:,35).*((CONSTANTS(:,73) - STATES(:,1))./CONSTANTS(:,73)+ 1.50000.*power((CONSTANTS(:,73) - STATES(:,1))./CONSTANTS(:,73), 2.00000));
    ALGEBRAIC(:,38) = (((ALGEBRAIC(:,13)+ALGEBRAIC(:,25))./2.00000 - ALGEBRAIC(:,25)) - ( CONSTANTS(:,143).*CONSTANTS(:,73))./STATES(:,1))+ALGEBRAIC(:,36);
    ALGEBRAIC(:,41) = piecewise({ALGEBRAIC(:,38)<=0.00000, power(( CONSTANTS(:,63).*power(1.00000 - ALGEBRAIC(:,38)./CONSTANTS(:,67),  - CONSTANTS(:,65))), 1.0 ./ 2) , ALGEBRAIC(:,38)>=0.00000, power((CONSTANTS(:,64) -  (CONSTANTS(:,64) - CONSTANTS(:,63)).*power(1.00000 - ALGEBRAIC(:,38)./CONSTANTS(:,68),  - CONSTANTS(:,66))), 1.0 ./ 2) }, NaN);
    RATES(:,1) =  CONSTANTS(:,69).*(ALGEBRAIC(:,41) - STATES(:,1));
    ALGEBRAIC(:,44) = 0.0100000./ALGEBRAIC(:,32);
    ALGEBRAIC(:,48) = STATES(:,23)+ ALGEBRAIC(:,44).*(STATES(:,16) - STATES(:,6));
    ALGEBRAIC(:,29) = ( CONSTANTS(:,81).*CONSTANTS(:,83))./(  pi.*power(STATES(:,2), 2.00000));
    RATES(:,16) = ((ALGEBRAIC(:,13) - ALGEBRAIC(:,48)) -  (ALGEBRAIC(:,33)./2.00000).*STATES(:,16))./(ALGEBRAIC(:,29)./2.00000);
    ALGEBRAIC(:,37) = ( CONSTANTS(:,97).*CONSTANTS(:,98))./power((power(CONSTANTS(:,98), 2.00000)+power( CONSTANTS(:,146).*ALGEBRAIC(:,33), 2.00000)), 1.0 ./ 2);
    ALGEBRAIC(:,39) = atan(( CONSTANTS(:,146).*ALGEBRAIC(:,33))./CONSTANTS(:,98));
    ALGEBRAIC(:,40) = CONSTANTS(:,96)+ ALGEBRAIC(:,37).* sin( CONSTANTS(:,146).*VOI - ALGEBRAIC(:,39));
    RATES(:,6) = ((ALGEBRAIC(:,48) - ALGEBRAIC(:,40)) -  (ALGEBRAIC(:,33)./2.00000).*STATES(:,6))./(ALGEBRAIC(:,29)./2.00000);
    ALGEBRAIC(:,46) = ( 2.00000.* pi.*power(STATES(:,3), 3.00000).*CONSTANTS(:,104))./( CONSTANTS(:,103).*CONSTANTS(:,114));
    RATES(:,24) = (STATES(:,20) - STATES(:,7))./ALGEBRAIC(:,46);
    ALGEBRAIC(:,50) = ( 8.00000.*CONSTANTS(:,101).*CONSTANTS(:,104))./(  pi.*power(STATES(:,3), 4.00000));
    ALGEBRAIC(:,51) =  STATES(:,20).*ALGEBRAIC(:,50);
    ALGEBRAIC(:,52) = abs( (CONSTANTS(:,100)./3.00000).*( ALGEBRAIC(:,34).*power(STATES(:,2), 4.00000)+ ALGEBRAIC(:,51).*power(STATES(:,3), 4.00000)))./2.00000;
    ALGEBRAIC(:,53) =  2.00000.*ALGEBRAIC(:,52).*((CONSTANTS(:,94) - STATES(:,2))./CONSTANTS(:,94)+ 1.50000.*power((CONSTANTS(:,94) - STATES(:,2))./CONSTANTS(:,94), 2.00000));
    ALGEBRAIC(:,56) = (((ALGEBRAIC(:,13)+ALGEBRAIC(:,40))./2.00000 - ALGEBRAIC(:,40)) - ( CONSTANTS(:,143).*CONSTANTS(:,94))./STATES(:,2))+ALGEBRAIC(:,53);
    ALGEBRAIC(:,61) = piecewise({ALGEBRAIC(:,56)<=0.00000, power(( CONSTANTS(:,84).*power(1.00000 - ALGEBRAIC(:,56)./CONSTANTS(:,88),  - CONSTANTS(:,86))), 1.0 ./ 2) , ALGEBRAIC(:,56)>=0.00000, power((CONSTANTS(:,85) -  (CONSTANTS(:,85) - CONSTANTS(:,84)).*power(1.00000 - ALGEBRAIC(:,56)./CONSTANTS(:,89),  - CONSTANTS(:,87))), 1.0 ./ 2) }, NaN);
    RATES(:,2) =  CONSTANTS(:,90).*(ALGEBRAIC(:,61) - STATES(:,2));
    ALGEBRAIC(:,55) =  0.500000.*ALGEBRAIC(:,35)+ 0.500000.*ALGEBRAIC(:,52);
    ALGEBRAIC(:,58) =  2.00000.*ALGEBRAIC(:,55).*((CONSTANTS(:,37) - STATES(:,17))./CONSTANTS(:,37)+ 1.50000.*power((CONSTANTS(:,37) - STATES(:,17))./CONSTANTS(:,37), 2.00000));
    ALGEBRAIC(:,60) = (ALGEBRAIC(:,7) - ( CONSTANTS(:,143).*CONSTANTS(:,37))./STATES(:,17))+ALGEBRAIC(:,58);
    ALGEBRAIC(:,64) = piecewise({ALGEBRAIC(:,60)<=0.00000, power(( CONSTANTS(:,27).*power(1.00000 - ALGEBRAIC(:,60)./CONSTANTS(:,31),  - CONSTANTS(:,29))), 1.0 ./ 2) , ALGEBRAIC(:,60)>=0.00000, power((CONSTANTS(:,28) -  (CONSTANTS(:,28) - CONSTANTS(:,27)).*power(1.00000 - ALGEBRAIC(:,60)./CONSTANTS(:,32),  - CONSTANTS(:,30))), 1.0 ./ 2) }, NaN);
    RATES(:,17) =  CONSTANTS(:,33).*(ALGEBRAIC(:,64) - STATES(:,17));
    ALGEBRAIC(:,65) = 0.0100000./ALGEBRAIC(:,46);
    ALGEBRAIC(:,69) = STATES(:,24)+ ALGEBRAIC(:,65).*(STATES(:,20) - STATES(:,7));
    ALGEBRAIC(:,42) = ( CONSTANTS(:,102).*CONSTANTS(:,104))./(  pi.*power(STATES(:,3), 2.00000));
    RATES(:,20) = ((ALGEBRAIC(:,19) - ALGEBRAIC(:,69)) -  (ALGEBRAIC(:,50)./2.00000).*STATES(:,20))./(ALGEBRAIC(:,42)./2.00000);
    ALGEBRAIC(:,54) = ( CONSTANTS(:,118).*CONSTANTS(:,119))./power((power(CONSTANTS(:,119), 2.00000)+power( CONSTANTS(:,147).*ALGEBRAIC(:,50), 2.00000)), 1.0 ./ 2);
    ALGEBRAIC(:,57) = atan(( CONSTANTS(:,147).*ALGEBRAIC(:,50))./CONSTANTS(:,119));
    ALGEBRAIC(:,59) = CONSTANTS(:,117)+ ALGEBRAIC(:,54).* sin( CONSTANTS(:,147).*VOI - ALGEBRAIC(:,57));
    RATES(:,7) = ((ALGEBRAIC(:,69) - ALGEBRAIC(:,59)) -  (ALGEBRAIC(:,50)./2.00000).*STATES(:,7))./(ALGEBRAIC(:,42)./2.00000);
    ALGEBRAIC(:,68) = ( 2.00000.* pi.*power(STATES(:,4), 3.00000).*CONSTANTS(:,125))./( CONSTANTS(:,124).*CONSTANTS(:,135));
    RATES(:,25) = (STATES(:,21) - STATES(:,8))./ALGEBRAIC(:,68);
    ALGEBRAIC(:,71) = ( 8.00000.*CONSTANTS(:,122).*CONSTANTS(:,125))./(  pi.*power(STATES(:,4), 4.00000));
    ALGEBRAIC(:,72) =  STATES(:,21).*ALGEBRAIC(:,71);
    ALGEBRAIC(:,73) = abs( (CONSTANTS(:,121)./3.00000).*( ALGEBRAIC(:,51).*power(STATES(:,3), 4.00000)+ ALGEBRAIC(:,72).*power(STATES(:,4), 4.00000)))./2.00000;
    ALGEBRAIC(:,74) =  2.00000.*ALGEBRAIC(:,73).*((CONSTANTS(:,115) - STATES(:,3))./CONSTANTS(:,115)+ 1.50000.*power((CONSTANTS(:,115) - STATES(:,3))./CONSTANTS(:,115), 2.00000));
    ALGEBRAIC(:,76) = (((ALGEBRAIC(:,19)+ALGEBRAIC(:,59))./2.00000 - ALGEBRAIC(:,59)) - ( CONSTANTS(:,143).*CONSTANTS(:,115))./STATES(:,3))+ALGEBRAIC(:,74);
    ALGEBRAIC(:,83) = piecewise({ALGEBRAIC(:,76)<=0.00000, power(( CONSTANTS(:,105).*power(1.00000 - ALGEBRAIC(:,76)./CONSTANTS(:,109),  - CONSTANTS(:,107))), 1.0 ./ 2) , ALGEBRAIC(:,76)>=0.00000, power((CONSTANTS(:,106) -  (CONSTANTS(:,106) - CONSTANTS(:,105)).*power(1.00000 - ALGEBRAIC(:,76)./CONSTANTS(:,110),  - CONSTANTS(:,108))), 1.0 ./ 2) }, NaN);
    RATES(:,3) =  CONSTANTS(:,111).*(ALGEBRAIC(:,83) - STATES(:,3));
    ALGEBRAIC(:,75) = abs( (CONSTANTS(:,142)./3.00000).*( ALGEBRAIC(:,72).*power(STATES(:,4), 4.00000)+ ALGEBRAIC(:,26).*power(STATES(:,1), 4.00000)))./2.00000;
    ALGEBRAIC(:,78) =  0.250000.*ALGEBRAIC(:,35)+ 0.250000.*ALGEBRAIC(:,52)+ 0.250000.*ALGEBRAIC(:,73)+ 0.250000.*ALGEBRAIC(:,75);
    ALGEBRAIC(:,81) =  2.00000.*ALGEBRAIC(:,78).*((CONSTANTS(:,16) - STATES(:,13))./CONSTANTS(:,16)+ 1.50000.*power((CONSTANTS(:,16) - STATES(:,13))./CONSTANTS(:,16), 2.00000));
    ALGEBRAIC(:,85) = (ALGEBRAIC(:,1) - ( CONSTANTS(:,143).*CONSTANTS(:,16))./STATES(:,13))+ALGEBRAIC(:,81);
    ALGEBRAIC(:,88) = piecewise({ALGEBRAIC(:,85)<=0.00000, power(( CONSTANTS(:,6).*power(1.00000 - ALGEBRAIC(:,85)./CONSTANTS(:,10),  - CONSTANTS(:,8))), 1.0 ./ 2) , ALGEBRAIC(:,85)>=0.00000, power((CONSTANTS(:,7) -  (CONSTANTS(:,7) - CONSTANTS(:,6)).*power(1.00000 - ALGEBRAIC(:,85)./CONSTANTS(:,11),  - CONSTANTS(:,9))), 1.0 ./ 2) }, NaN);
    RATES(:,13) =  CONSTANTS(:,12).*(ALGEBRAIC(:,88) - STATES(:,13));
    ALGEBRAIC(:,79) =  0.500000.*ALGEBRAIC(:,73)+ 0.500000.*ALGEBRAIC(:,75);
    ALGEBRAIC(:,82) =  2.00000.*ALGEBRAIC(:,79).*((CONSTANTS(:,55) - STATES(:,18))./CONSTANTS(:,55)+ 1.50000.*power((CONSTANTS(:,55) - STATES(:,18))./CONSTANTS(:,55), 2.00000));
    ALGEBRAIC(:,86) = (ALGEBRAIC(:,7) - ( CONSTANTS(:,143).*CONSTANTS(:,55))./STATES(:,18))+ALGEBRAIC(:,82);
    ALGEBRAIC(:,89) = piecewise({ALGEBRAIC(:,86)<=0.00000, power(( CONSTANTS(:,45).*power(1.00000 - ALGEBRAIC(:,86)./CONSTANTS(:,49),  - CONSTANTS(:,47))), 1.0 ./ 2) , ALGEBRAIC(:,86)>=0.00000, power((CONSTANTS(:,46) -  (CONSTANTS(:,46) - CONSTANTS(:,45)).*power(1.00000 - ALGEBRAIC(:,86)./CONSTANTS(:,50),  - CONSTANTS(:,48))), 1.0 ./ 2) }, NaN);
    RATES(:,18) =  CONSTANTS(:,51).*(ALGEBRAIC(:,89) - STATES(:,18));
    ALGEBRAIC(:,91) = 0.0100000./ALGEBRAIC(:,68);
    ALGEBRAIC(:,95) = STATES(:,25)+ ALGEBRAIC(:,91).*(STATES(:,21) - STATES(:,8));
    ALGEBRAIC(:,63) = ( CONSTANTS(:,123).*CONSTANTS(:,125))./(  pi.*power(STATES(:,4), 2.00000));
    RATES(:,21) = ((ALGEBRAIC(:,19) - ALGEBRAIC(:,95)) -  (ALGEBRAIC(:,71)./2.00000).*STATES(:,21))./(ALGEBRAIC(:,63)./2.00000);
    ALGEBRAIC(:,77) = ( CONSTANTS(:,139).*CONSTANTS(:,140))./power((power(CONSTANTS(:,140), 2.00000)+power( CONSTANTS(:,148).*ALGEBRAIC(:,71), 2.00000)), 1.0 ./ 2);
    ALGEBRAIC(:,80) = atan(( CONSTANTS(:,148).*ALGEBRAIC(:,71))./CONSTANTS(:,140));
    ALGEBRAIC(:,84) = CONSTANTS(:,138)+ ALGEBRAIC(:,77).* sin( CONSTANTS(:,148).*VOI - ALGEBRAIC(:,80));
    RATES(:,8) = ((ALGEBRAIC(:,95) - ALGEBRAIC(:,84)) -  (ALGEBRAIC(:,71)./2.00000).*STATES(:,8))./(ALGEBRAIC(:,63)./2.00000);
    ALGEBRAIC(:,87) =  2.00000.*ALGEBRAIC(:,75).*((CONSTANTS(:,136) - STATES(:,4))./CONSTANTS(:,136)+ 1.50000.*power((CONSTANTS(:,136) - STATES(:,4))./CONSTANTS(:,136), 2.00000));
    ALGEBRAIC(:,93) = (((ALGEBRAIC(:,19)+ALGEBRAIC(:,84))./2.00000 - ALGEBRAIC(:,84)) - ( CONSTANTS(:,143).*CONSTANTS(:,136))./STATES(:,4))+ALGEBRAIC(:,87);
    ALGEBRAIC(:,97) = piecewise({ALGEBRAIC(:,93)<=0.00000, power(( CONSTANTS(:,126).*power(1.00000 - ALGEBRAIC(:,93)./CONSTANTS(:,130),  - CONSTANTS(:,128))), 1.0 ./ 2) , ALGEBRAIC(:,93)>=0.00000, power((CONSTANTS(:,127) -  (CONSTANTS(:,127) - CONSTANTS(:,126)).*power(1.00000 - ALGEBRAIC(:,93)./CONSTANTS(:,131),  - CONSTANTS(:,129))), 1.0 ./ 2) }, NaN);
    RATES(:,4) =  CONSTANTS(:,132).*(ALGEBRAIC(:,97) - STATES(:,4));
   RATES = RATES';
end

% Calculate algebraic variables
function ALGEBRAIC = computeAlgebraic(ALGEBRAIC, CONSTANTS, STATES, VOI)
    statesSize = size(STATES);
    statesColumnCount = statesSize(2);
    if ( statesColumnCount == 1)
        STATES = STATES';
        utilOnes = 1;
    else
        statesRowCount = statesSize(1);
        utilOnes = ones(statesRowCount, 1);
    end
    ALGEBRAIC(:,3) = ( 2.00000.* pi.*power(STATES(:,13), 3.00000).*CONSTANTS(:,5))./( CONSTANTS(:,4).*CONSTANTS(:,15));
    ALGEBRAIC(:,6) = 0.0100000./ALGEBRAIC(:,3);
    ALGEBRAIC(:,7) = STATES(:,9)+ ALGEBRAIC(:,6).*((STATES(:,12) - STATES(:,10)) - STATES(:,11));
    ALGEBRAIC(:,1) = CONSTANTS(:,18)+ CONSTANTS(:,19).* sin( CONSTANTS(:,144).*VOI);
    ALGEBRAIC(:,4) = ( 8.00000.*CONSTANTS(:,2).*CONSTANTS(:,5))./(  pi.*power(STATES(:,13), 4.00000));
    ALGEBRAIC(:,2) = ( CONSTANTS(:,3).*CONSTANTS(:,5))./(  pi.*power(STATES(:,13), 2.00000));
    ALGEBRAIC(:,9) = ( 2.00000.* pi.*power(STATES(:,17), 3.00000).*CONSTANTS(:,26))./( CONSTANTS(:,25).*CONSTANTS(:,36));
    ALGEBRAIC(:,12) = 0.0100000./ALGEBRAIC(:,9);
    ALGEBRAIC(:,13) = STATES(:,14)+ ALGEBRAIC(:,12).*((STATES(:,10) - STATES(:,15)) - STATES(:,16));
    ALGEBRAIC(:,10) = ( 8.00000.*CONSTANTS(:,23).*CONSTANTS(:,26))./(  pi.*power(STATES(:,17), 4.00000));
    ALGEBRAIC(:,8) = ( CONSTANTS(:,24).*CONSTANTS(:,26))./(  pi.*power(STATES(:,17), 2.00000));
    ALGEBRAIC(:,15) = ( 2.00000.* pi.*power(STATES(:,18), 3.00000).*CONSTANTS(:,44))./( CONSTANTS(:,43).*CONSTANTS(:,54));
    ALGEBRAIC(:,18) = 0.0100000./ALGEBRAIC(:,15);
    ALGEBRAIC(:,19) = STATES(:,19)+ ALGEBRAIC(:,18).*((STATES(:,11) - STATES(:,20)) - STATES(:,21));
    ALGEBRAIC(:,16) = ( 8.00000.*CONSTANTS(:,41).*CONSTANTS(:,44))./(  pi.*power(STATES(:,18), 4.00000));
    ALGEBRAIC(:,14) = ( CONSTANTS(:,42).*CONSTANTS(:,44))./(  pi.*power(STATES(:,18), 2.00000));
    ALGEBRAIC(:,21) = ( 2.00000.* pi.*power(STATES(:,1), 3.00000).*CONSTANTS(:,62))./( CONSTANTS(:,61).*CONSTANTS(:,72));
    ALGEBRAIC(:,27) = 0.0100000./ALGEBRAIC(:,21);
    ALGEBRAIC(:,30) = STATES(:,22)+ ALGEBRAIC(:,27).*(STATES(:,15) - STATES(:,5));
    ALGEBRAIC(:,22) = ( 8.00000.*CONSTANTS(:,59).*CONSTANTS(:,62))./(  pi.*power(STATES(:,1), 4.00000));
    ALGEBRAIC(:,20) = ( CONSTANTS(:,60).*CONSTANTS(:,62))./(  pi.*power(STATES(:,1), 2.00000));
    ALGEBRAIC(:,23) = ( CONSTANTS(:,76).*CONSTANTS(:,77))./power((power(CONSTANTS(:,77), 2.00000)+power( CONSTANTS(:,145).*ALGEBRAIC(:,22), 2.00000)), 1.0 ./ 2);
    ALGEBRAIC(:,24) = atan(( CONSTANTS(:,145).*ALGEBRAIC(:,22))./CONSTANTS(:,77));
    ALGEBRAIC(:,25) = CONSTANTS(:,75)+ ALGEBRAIC(:,23).* sin( CONSTANTS(:,145).*VOI - ALGEBRAIC(:,24));
    ALGEBRAIC(:,32) = ( 2.00000.* pi.*power(STATES(:,2), 3.00000).*CONSTANTS(:,83))./( CONSTANTS(:,82).*CONSTANTS(:,93));
    ALGEBRAIC(:,26) =  STATES(:,15).*ALGEBRAIC(:,22);
    ALGEBRAIC(:,33) = ( 8.00000.*CONSTANTS(:,80).*CONSTANTS(:,83))./(  pi.*power(STATES(:,2), 4.00000));
    ALGEBRAIC(:,34) =  STATES(:,16).*ALGEBRAIC(:,33);
    ALGEBRAIC(:,35) = abs( (CONSTANTS(:,79)./3.00000).*( ALGEBRAIC(:,26).*power(STATES(:,1), 4.00000)+ ALGEBRAIC(:,34).*power(STATES(:,2), 4.00000)))./2.00000;
    ALGEBRAIC(:,36) =  2.00000.*ALGEBRAIC(:,35).*((CONSTANTS(:,73) - STATES(:,1))./CONSTANTS(:,73)+ 1.50000.*power((CONSTANTS(:,73) - STATES(:,1))./CONSTANTS(:,73), 2.00000));
    ALGEBRAIC(:,38) = (((ALGEBRAIC(:,13)+ALGEBRAIC(:,25))./2.00000 - ALGEBRAIC(:,25)) - ( CONSTANTS(:,143).*CONSTANTS(:,73))./STATES(:,1))+ALGEBRAIC(:,36);
    ALGEBRAIC(:,41) = piecewise({ALGEBRAIC(:,38)<=0.00000, power(( CONSTANTS(:,63).*power(1.00000 - ALGEBRAIC(:,38)./CONSTANTS(:,67),  - CONSTANTS(:,65))), 1.0 ./ 2) , ALGEBRAIC(:,38)>=0.00000, power((CONSTANTS(:,64) -  (CONSTANTS(:,64) - CONSTANTS(:,63)).*power(1.00000 - ALGEBRAIC(:,38)./CONSTANTS(:,68),  - CONSTANTS(:,66))), 1.0 ./ 2) }, NaN);
    ALGEBRAIC(:,44) = 0.0100000./ALGEBRAIC(:,32);
    ALGEBRAIC(:,48) = STATES(:,23)+ ALGEBRAIC(:,44).*(STATES(:,16) - STATES(:,6));
    ALGEBRAIC(:,29) = ( CONSTANTS(:,81).*CONSTANTS(:,83))./(  pi.*power(STATES(:,2), 2.00000));
    ALGEBRAIC(:,37) = ( CONSTANTS(:,97).*CONSTANTS(:,98))./power((power(CONSTANTS(:,98), 2.00000)+power( CONSTANTS(:,146).*ALGEBRAIC(:,33), 2.00000)), 1.0 ./ 2);
    ALGEBRAIC(:,39) = atan(( CONSTANTS(:,146).*ALGEBRAIC(:,33))./CONSTANTS(:,98));
    ALGEBRAIC(:,40) = CONSTANTS(:,96)+ ALGEBRAIC(:,37).* sin( CONSTANTS(:,146).*VOI - ALGEBRAIC(:,39));
    ALGEBRAIC(:,46) = ( 2.00000.* pi.*power(STATES(:,3), 3.00000).*CONSTANTS(:,104))./( CONSTANTS(:,103).*CONSTANTS(:,114));
    ALGEBRAIC(:,50) = ( 8.00000.*CONSTANTS(:,101).*CONSTANTS(:,104))./(  pi.*power(STATES(:,3), 4.00000));
    ALGEBRAIC(:,51) =  STATES(:,20).*ALGEBRAIC(:,50);
    ALGEBRAIC(:,52) = abs( (CONSTANTS(:,100)./3.00000).*( ALGEBRAIC(:,34).*power(STATES(:,2), 4.00000)+ ALGEBRAIC(:,51).*power(STATES(:,3), 4.00000)))./2.00000;
    ALGEBRAIC(:,53) =  2.00000.*ALGEBRAIC(:,52).*((CONSTANTS(:,94) - STATES(:,2))./CONSTANTS(:,94)+ 1.50000.*power((CONSTANTS(:,94) - STATES(:,2))./CONSTANTS(:,94), 2.00000));
    ALGEBRAIC(:,56) = (((ALGEBRAIC(:,13)+ALGEBRAIC(:,40))./2.00000 - ALGEBRAIC(:,40)) - ( CONSTANTS(:,143).*CONSTANTS(:,94))./STATES(:,2))+ALGEBRAIC(:,53);
    ALGEBRAIC(:,61) = piecewise({ALGEBRAIC(:,56)<=0.00000, power(( CONSTANTS(:,84).*power(1.00000 - ALGEBRAIC(:,56)./CONSTANTS(:,88),  - CONSTANTS(:,86))), 1.0 ./ 2) , ALGEBRAIC(:,56)>=0.00000, power((CONSTANTS(:,85) -  (CONSTANTS(:,85) - CONSTANTS(:,84)).*power(1.00000 - ALGEBRAIC(:,56)./CONSTANTS(:,89),  - CONSTANTS(:,87))), 1.0 ./ 2) }, NaN);
    ALGEBRAIC(:,55) =  0.500000.*ALGEBRAIC(:,35)+ 0.500000.*ALGEBRAIC(:,52);
    ALGEBRAIC(:,58) =  2.00000.*ALGEBRAIC(:,55).*((CONSTANTS(:,37) - STATES(:,17))./CONSTANTS(:,37)+ 1.50000.*power((CONSTANTS(:,37) - STATES(:,17))./CONSTANTS(:,37), 2.00000));
    ALGEBRAIC(:,60) = (ALGEBRAIC(:,7) - ( CONSTANTS(:,143).*CONSTANTS(:,37))./STATES(:,17))+ALGEBRAIC(:,58);
    ALGEBRAIC(:,64) = piecewise({ALGEBRAIC(:,60)<=0.00000, power(( CONSTANTS(:,27).*power(1.00000 - ALGEBRAIC(:,60)./CONSTANTS(:,31),  - CONSTANTS(:,29))), 1.0 ./ 2) , ALGEBRAIC(:,60)>=0.00000, power((CONSTANTS(:,28) -  (CONSTANTS(:,28) - CONSTANTS(:,27)).*power(1.00000 - ALGEBRAIC(:,60)./CONSTANTS(:,32),  - CONSTANTS(:,30))), 1.0 ./ 2) }, NaN);
    ALGEBRAIC(:,65) = 0.0100000./ALGEBRAIC(:,46);
    ALGEBRAIC(:,69) = STATES(:,24)+ ALGEBRAIC(:,65).*(STATES(:,20) - STATES(:,7));
    ALGEBRAIC(:,42) = ( CONSTANTS(:,102).*CONSTANTS(:,104))./(  pi.*power(STATES(:,3), 2.00000));
    ALGEBRAIC(:,54) = ( CONSTANTS(:,118).*CONSTANTS(:,119))./power((power(CONSTANTS(:,119), 2.00000)+power( CONSTANTS(:,147).*ALGEBRAIC(:,50), 2.00000)), 1.0 ./ 2);
    ALGEBRAIC(:,57) = atan(( CONSTANTS(:,147).*ALGEBRAIC(:,50))./CONSTANTS(:,119));
    ALGEBRAIC(:,59) = CONSTANTS(:,117)+ ALGEBRAIC(:,54).* sin( CONSTANTS(:,147).*VOI - ALGEBRAIC(:,57));
    ALGEBRAIC(:,68) = ( 2.00000.* pi.*power(STATES(:,4), 3.00000).*CONSTANTS(:,125))./( CONSTANTS(:,124).*CONSTANTS(:,135));
    ALGEBRAIC(:,71) = ( 8.00000.*CONSTANTS(:,122).*CONSTANTS(:,125))./(  pi.*power(STATES(:,4), 4.00000));
    ALGEBRAIC(:,72) =  STATES(:,21).*ALGEBRAIC(:,71);
    ALGEBRAIC(:,73) = abs( (CONSTANTS(:,121)./3.00000).*( ALGEBRAIC(:,51).*power(STATES(:,3), 4.00000)+ ALGEBRAIC(:,72).*power(STATES(:,4), 4.00000)))./2.00000;
    ALGEBRAIC(:,74) =  2.00000.*ALGEBRAIC(:,73).*((CONSTANTS(:,115) - STATES(:,3))./CONSTANTS(:,115)+ 1.50000.*power((CONSTANTS(:,115) - STATES(:,3))./CONSTANTS(:,115), 2.00000));
    ALGEBRAIC(:,76) = (((ALGEBRAIC(:,19)+ALGEBRAIC(:,59))./2.00000 - ALGEBRAIC(:,59)) - ( CONSTANTS(:,143).*CONSTANTS(:,115))./STATES(:,3))+ALGEBRAIC(:,74);
    ALGEBRAIC(:,83) = piecewise({ALGEBRAIC(:,76)<=0.00000, power(( CONSTANTS(:,105).*power(1.00000 - ALGEBRAIC(:,76)./CONSTANTS(:,109),  - CONSTANTS(:,107))), 1.0 ./ 2) , ALGEBRAIC(:,76)>=0.00000, power((CONSTANTS(:,106) -  (CONSTANTS(:,106) - CONSTANTS(:,105)).*power(1.00000 - ALGEBRAIC(:,76)./CONSTANTS(:,110),  - CONSTANTS(:,108))), 1.0 ./ 2) }, NaN);
    ALGEBRAIC(:,75) = abs( (CONSTANTS(:,142)./3.00000).*( ALGEBRAIC(:,72).*power(STATES(:,4), 4.00000)+ ALGEBRAIC(:,26).*power(STATES(:,1), 4.00000)))./2.00000;
    ALGEBRAIC(:,78) =  0.250000.*ALGEBRAIC(:,35)+ 0.250000.*ALGEBRAIC(:,52)+ 0.250000.*ALGEBRAIC(:,73)+ 0.250000.*ALGEBRAIC(:,75);
    ALGEBRAIC(:,81) =  2.00000.*ALGEBRAIC(:,78).*((CONSTANTS(:,16) - STATES(:,13))./CONSTANTS(:,16)+ 1.50000.*power((CONSTANTS(:,16) - STATES(:,13))./CONSTANTS(:,16), 2.00000));
    ALGEBRAIC(:,85) = (ALGEBRAIC(:,1) - ( CONSTANTS(:,143).*CONSTANTS(:,16))./STATES(:,13))+ALGEBRAIC(:,81);
    ALGEBRAIC(:,88) = piecewise({ALGEBRAIC(:,85)<=0.00000, power(( CONSTANTS(:,6).*power(1.00000 - ALGEBRAIC(:,85)./CONSTANTS(:,10),  - CONSTANTS(:,8))), 1.0 ./ 2) , ALGEBRAIC(:,85)>=0.00000, power((CONSTANTS(:,7) -  (CONSTANTS(:,7) - CONSTANTS(:,6)).*power(1.00000 - ALGEBRAIC(:,85)./CONSTANTS(:,11),  - CONSTANTS(:,9))), 1.0 ./ 2) }, NaN);
    ALGEBRAIC(:,79) =  0.500000.*ALGEBRAIC(:,73)+ 0.500000.*ALGEBRAIC(:,75);
    ALGEBRAIC(:,82) =  2.00000.*ALGEBRAIC(:,79).*((CONSTANTS(:,55) - STATES(:,18))./CONSTANTS(:,55)+ 1.50000.*power((CONSTANTS(:,55) - STATES(:,18))./CONSTANTS(:,55), 2.00000));
    ALGEBRAIC(:,86) = (ALGEBRAIC(:,7) - ( CONSTANTS(:,143).*CONSTANTS(:,55))./STATES(:,18))+ALGEBRAIC(:,82);
    ALGEBRAIC(:,89) = piecewise({ALGEBRAIC(:,86)<=0.00000, power(( CONSTANTS(:,45).*power(1.00000 - ALGEBRAIC(:,86)./CONSTANTS(:,49),  - CONSTANTS(:,47))), 1.0 ./ 2) , ALGEBRAIC(:,86)>=0.00000, power((CONSTANTS(:,46) -  (CONSTANTS(:,46) - CONSTANTS(:,45)).*power(1.00000 - ALGEBRAIC(:,86)./CONSTANTS(:,50),  - CONSTANTS(:,48))), 1.0 ./ 2) }, NaN);
    ALGEBRAIC(:,91) = 0.0100000./ALGEBRAIC(:,68);
    ALGEBRAIC(:,95) = STATES(:,25)+ ALGEBRAIC(:,91).*(STATES(:,21) - STATES(:,8));
    ALGEBRAIC(:,63) = ( CONSTANTS(:,123).*CONSTANTS(:,125))./(  pi.*power(STATES(:,4), 2.00000));
    ALGEBRAIC(:,77) = ( CONSTANTS(:,139).*CONSTANTS(:,140))./power((power(CONSTANTS(:,140), 2.00000)+power( CONSTANTS(:,148).*ALGEBRAIC(:,71), 2.00000)), 1.0 ./ 2);
    ALGEBRAIC(:,80) = atan(( CONSTANTS(:,148).*ALGEBRAIC(:,71))./CONSTANTS(:,140));
    ALGEBRAIC(:,84) = CONSTANTS(:,138)+ ALGEBRAIC(:,77).* sin( CONSTANTS(:,148).*VOI - ALGEBRAIC(:,80));
    ALGEBRAIC(:,87) =  2.00000.*ALGEBRAIC(:,75).*((CONSTANTS(:,136) - STATES(:,4))./CONSTANTS(:,136)+ 1.50000.*power((CONSTANTS(:,136) - STATES(:,4))./CONSTANTS(:,136), 2.00000));
    ALGEBRAIC(:,93) = (((ALGEBRAIC(:,19)+ALGEBRAIC(:,84))./2.00000 - ALGEBRAIC(:,84)) - ( CONSTANTS(:,143).*CONSTANTS(:,136))./STATES(:,4))+ALGEBRAIC(:,87);
    ALGEBRAIC(:,97) = piecewise({ALGEBRAIC(:,93)<=0.00000, power(( CONSTANTS(:,126).*power(1.00000 - ALGEBRAIC(:,93)./CONSTANTS(:,130),  - CONSTANTS(:,128))), 1.0 ./ 2) , ALGEBRAIC(:,93)>=0.00000, power((CONSTANTS(:,127) -  (CONSTANTS(:,127) - CONSTANTS(:,126)).*power(1.00000 - ALGEBRAIC(:,93)./CONSTANTS(:,131),  - CONSTANTS(:,129))), 1.0 ./ 2) }, NaN);
    ALGEBRAIC(:,5) =  STATES(:,12).*ALGEBRAIC(:,4);
    ALGEBRAIC(:,11) =  STATES(:,10).*ALGEBRAIC(:,10);
    ALGEBRAIC(:,17) =  STATES(:,11).*ALGEBRAIC(:,16);
    ALGEBRAIC(:,28) = ( 0.200000.*CONSTANTS(:,78)+ALGEBRAIC(:,25)./CONSTANTS(:,77))./CONSTANTS(:,78);
    ALGEBRAIC(:,31) = 1.00000 - STATES(:,1)./power(ALGEBRAIC(:,28), 1.00000./3.00000);
    ALGEBRAIC(:,43) = ( 0.200000.*CONSTANTS(:,39)+ALGEBRAIC(:,40)./CONSTANTS(:,38))./CONSTANTS(:,39);
    ALGEBRAIC(:,45) = ( 0.200000.*CONSTANTS(:,99)+ALGEBRAIC(:,40)./CONSTANTS(:,98))./CONSTANTS(:,99);
    ALGEBRAIC(:,47) = 1.00000 - STATES(:,17)./power(ALGEBRAIC(:,43), 1.00000./3.00000);
    ALGEBRAIC(:,49) = 1.00000 - STATES(:,2)./power(ALGEBRAIC(:,45), 1.00000./3.00000);
    ALGEBRAIC(:,62) = ( 0.200000.*CONSTANTS(:,21)+ALGEBRAIC(:,59)./CONSTANTS(:,20))./CONSTANTS(:,21);
    ALGEBRAIC(:,66) = ( 0.200000.*CONSTANTS(:,120)+ALGEBRAIC(:,59)./CONSTANTS(:,119))./CONSTANTS(:,120);
    ALGEBRAIC(:,67) = 1.00000 - STATES(:,13)./power(ALGEBRAIC(:,62), 1.00000./3.00000);
    ALGEBRAIC(:,70) = 1.00000 - STATES(:,3)./power(ALGEBRAIC(:,66), 1.00000./3.00000);
    ALGEBRAIC(:,90) = ( 0.200000.*CONSTANTS(:,57)+ALGEBRAIC(:,84)./CONSTANTS(:,56))./CONSTANTS(:,57);
    ALGEBRAIC(:,92) = ( 0.200000.*CONSTANTS(:,141)+ALGEBRAIC(:,84)./CONSTANTS(:,140))./CONSTANTS(:,141);
    ALGEBRAIC(:,94) = 1.00000 - STATES(:,18)./power(ALGEBRAIC(:,90), 1.00000./3.00000);
    ALGEBRAIC(:,96) = 1.00000 - STATES(:,4)./power(ALGEBRAIC(:,92), 1.00000./3.00000);
end

% Compute result of a piecewise function
function x = piecewise(cases, default)
    set = [0];
    for i = 1:2:length(cases)
        if (length(cases{i+1}) == 1)
            x(cases{i} & ~set,:) = cases{i+1};
        else
            x(cases{i} & ~set,:) = cases{i+1}(cases{i} & ~set);
        end
        set = set | cases{i};
        if(set), break, end
    end
    if (length(default) == 1)
        x(~set,:) = default;
    else
        x(~set,:) = default(~set);
    end
end

% Pad out or shorten strings to a set length
function strout = strpad(strin)
    req_length = 160;
    insize = size(strin,2);
    if insize > req_length
        strout = strin(1:req_length);
    else
        strout = [strin, blanks(req_length - insize)];
    end
end

